@@ -320,11 +320,11 @@ class DataPretreatment:
             else:
                 drop_df = pd.DataFrame(data={'field': drop})
                 print('因过多的缺失值而被舍弃的字段:\n', drop_df)
-        self.col_dict['drop_col'].extend(drop_col)
+        self.col_dict['drop_col'].extend(drop)
         end = time.time()
         if self.time_cost:
             print('耗时:', round(end - start, 4))
-        return nan_pd, drop_col
+        return nan_pd, drop
 
     def identify_type(
             self,
