@@ -278,6 +278,8 @@ class FeatureAnalysis:
         self.field_dict = self.field_dict if field_dict is None else field_dict
         self.label_first = self.label_first if label_first is None else label_first
         self.info_first = self.info_first if info_first is None else info_first
+        if self.label_first:
+            self.info_first = False
         self.corr = self.corr if corr is None else corr
         self.after_pretreatment = self.after_pretreatment if after_pretreatment is None else after_pretreatment
         self.init_box = self.init_box if init_box is None else init_box
@@ -369,7 +371,7 @@ class FeatureAnalysis:
                 max_value = max(v_label)
                 if k_label > max_value:
                     corr_drop.extend(v)
-                    corr_drop_name.append(field_name_list)
+                    corr_drop_name.extend(field_name_list)
                 else:
                     corr_drop.append(k)
                     corr_drop_name.append(k_name)
